{******************************************************************************}
{ Projeto: Componentes ACBr                                                    }
{  Biblioteca multiplataforma de componentes Delphi para interao com equipa- }
{ mentos de Automao Comercial utilizados no Brasil                           }
{                                                                              }
{ Direitos Autorais Reservados (c) 2020 Daniel Simoes de Almeida               }
{																			   }
{  Voc pode obter a ltima verso desse arquivo na pagina do  Projeto ACBr    }
{ Componentes localizado em      http://www.sourceforge.net/projects/acbr      }
{                                                                              }
{  Esta biblioteca  software livre; voc pode redistribu-la e/ou modific-la }
{ sob os termos da Licena Pblica Geral Menor do GNU conforme publicada pela  }
{ Free Software Foundation; tanto a verso 2.1 da Licena, ou (a seu critrio) }
{ qualquer verso posterior.                                                   }
{                                                                              }
{  Esta biblioteca  distribuda na expectativa de que seja til, porm, SEM   }
{ NENHUMA GARANTIA; nem mesmo a garantia implcita de COMERCIABILIDADE OU      }
{ ADEQUAO A UMA FINALIDADE ESPECFICA. Consulte a Licena Pblica Geral Menor}
{ do GNU para mais detalhes. (Arquivo LICENA.TXT ou LICENSE.TXT)              }
{                                                                              }
{  Voc deve ter recebido uma cpia da Licena Pblica Geral Menor do GNU junto}
{ com esta biblioteca; se no, escreva para a Free Software Foundation, Inc.,  }
{ no endereo 59 Temple Street, Suite 330, Boston, MA 02111-1307 USA.          }
{ Voc tambm pode obter uma copia da licena em:                              }
{ http://www.opensource.org/licenses/lgpl-license.php                          }
{                                                                              }
{ Daniel Simes de Almeida - daniel@projetoacbr.com.br - www.projetoacbr.com.br}
{       Rua Coronel Aureliano de Camargo, 963 - Tatu - SP - 18270-170         }
{******************************************************************************}

{$I ACBr.inc}

unit BalancaTeste1;

interface

uses
  Classes, SysUtils, Forms, Controls, Graphics, Dialogs, StdCtrls,
  Buttons, ExtCtrls, ACBrDevice, ACBrBAL, ACBrBase;

type

  { TForm1 }

  TForm1 = class(TForm)
    ACBrBAL1: TACBrBAL;
    btAtivarTara: TButton;
    btDesativarTara: TButton;
    btDesligarDisplay: TButton;
    btEnviarPrecoKg: TButton;
    btLigarDisplay: TButton;
    btnConectar: TButton;
    btnDesconectar: TButton;
    btnLerPeso: TButton;
    btSearchPorts: TSpeedButton;
    btZerarDispositivo: TButton;
    chbMonitorar: TCheckBox;
    edLog: TEdit;
    edPrecoKg: TEdit;
    edtTimeOut: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    Label8: TLabel;
    Label9: TLabel;
    Label10: TLabel;
    Label12: TLabel;
    Label11: TLabel;
    Memo1: TMemo;
    cmbBalanca: TComboBox;
    cmbBaudRate: TComboBox;
    cmbDataBits: TComboBox;
    cmbHandShaking: TComboBox;
    cmbParity: TComboBox;
    cmbPortaSerial: TComboBox;
    cmbStopBits: TComboBox;
    pnConfig: TPanel;
    pnOpcoesAdicionais: TPanel;
    pnOpcoes: TPanel;
    SbArqLog: TSpeedButton;
    sttPeso: TStaticText;
    sttResposta: TStaticText;
    procedure btAtivarTaraClick(Sender: TObject);
    procedure btDesativarTaraClick(Sender: TObject);
    procedure btDesligarDisplayClick(Sender: TObject);
    procedure btLigarDisplayClick(Sender: TObject);
    procedure btnConectarClick(Sender: TObject);
    procedure btnDesconectarClick(Sender: TObject);
    procedure btnLerPesoClick(Sender: TObject);
    procedure btEnviarPrecoKgClick(Sender: TObject);
    procedure btSearchPortsClick(Sender: TObject);
    procedure btZerarDispositivoClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var CloseAction: TCloseAction);
    procedure edtTimeOutKeyPress(Sender: TObject; var Key: Char);
    procedure chbMonitorarClick(Sender: TObject);
    procedure ACBrBAL1LePeso(Peso: Double; Resposta: AnsiString);
    procedure FormCreate(Sender : TObject) ;
    procedure SbArqLogClick(Sender: TObject);
  private
    { private declarations }
    function Converte(cmd: String): String;

    procedure InicializarBalanca(Ativar: Boolean);
  public
    { public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

uses
  typinfo, ACBrDeviceSerial, ACBrBALSelfCheckout,
  ACBrUtil.Base,
  ACBrUtil.FilesIO;

function TForm1.Converte(cmd: String): String;
var A : Integer ;
begin
  Result := '' ;
  For A := 1 to length( cmd ) do
  begin
     if not (cmd[A] in ['A'..'Z','a'..'z','0'..'9',
                        ' ','.',',','/','?','<','>',';',':',']','[','{','}',
                        '\','|','=','+','-','_',')','(','*','&','^','%','$',
                        '#','@','!','~' ]) then
        Result := Result + '#' + IntToStr(ord( cmd[A] )) + ' '
     else
        Result := Result + cmd[A] + ' ';
  end ;
end;

procedure TForm1.InicializarBalanca(Ativar: Boolean);
begin
  ACBrBAL1.Desativar;

  if Ativar then
  begin
    // configura porta de comunicao
    ACBrBAL1.Modelo           := TACBrBALModelo( cmbBalanca.ItemIndex );
    ACBrBAL1.Device.HandShake := TACBrHandShake( cmbHandShaking.ItemIndex );
    ACBrBAL1.Device.Parity    := TACBrSerialParity( cmbParity.ItemIndex );
    ACBrBAL1.Device.Stop      := TACBrSerialStop( cmbStopBits.ItemIndex );
    ACBrBAL1.Device.Data      := StrToInt( cmbDataBits.text );
    ACBrBAL1.Device.Baud      := StrToInt( cmbBaudRate.Text );
    ACBrBAL1.Device.Porta     := cmbPortaSerial.Text;
    ACBrBAL1.ArqLOG           := edLog.Text;

    // Conecta com a balana
    ACBrBAL1.Ativar;
  end;

  btnLerPeso.Enabled := Ativar;
  edPrecoKg.Enabled := Ativar;
  btEnviarPrecoKg.Enabled := Ativar;
  pnConfig.Enabled := (not Ativar);

  btnConectar.Enabled    := (not Ativar);
  btnConectar.Visible    := (not Ativar);
  btnDesconectar.Enabled := Ativar;
  btnDesconectar.Visible := Ativar;

  pnOpcoesAdicionais.Visible := Ativar and (ACBrBAL1.BAL is TACBrBALSelfCheckout);
end;

procedure TForm1.btnConectarClick(Sender: TObject);
begin
  InicializarBalanca(True);
end;

procedure TForm1.btDesativarTaraClick(Sender: TObject);
begin
  if (ACBrBAL1.BAL is TACBrBALSelfCheckout) then
    TACBrBALSelfCheckout(ACBrBAL1.BAL).DesativarTara;
end;

procedure TForm1.btDesligarDisplayClick(Sender: TObject);
begin
  if (ACBrBAL1.BAL is TACBrBALSelfCheckout) then
    TACBrBALSelfCheckout(ACBrBAL1.BAL).DesligarDisplay;
end;

procedure TForm1.btLigarDisplayClick(Sender: TObject);
begin
  if (ACBrBAL1.BAL is TACBrBALSelfCheckout) then
    TACBrBALSelfCheckout(ACBrBAL1.BAL).LigarDisplay;
end;

procedure TForm1.btAtivarTaraClick(Sender: TObject);
begin
  if (ACBrBAL1.BAL is TACBrBALSelfCheckout) then
    TACBrBALSelfCheckout(ACBrBAL1.BAL).AtivarTara;
end;

procedure TForm1.btnDesconectarClick(Sender: TObject);
begin
  InicializarBalanca(False);
end;

procedure TForm1.btnLerPesoClick(Sender: TObject);
Var TimeOut : Integer ;
begin
   try
      TimeOut := StrToInt( edtTimeOut.Text ) ;
   except
      TimeOut := 2000 ;
   end ;

   ACBrBAL1.LePeso( TimeOut );
end;

procedure TForm1.btEnviarPrecoKgClick(Sender: TObject);
var
  wTimeOut: Integer;
begin
  try
    wTimeOut := StrToInt(edtTimeOut.Text);
  except
    wTimeOut := 2000;
  end;

  if ACBrBAL1.EnviarPrecoKg(StringToFloatDef(edPrecoKg.Text, 0), wTimeOut) then
    Memo1.Lines.Add('Preo/Kg enviado com sucesso')
  else
    Memo1.Lines.Add('Erro ao enviar Preo/Kg');
end;

procedure TForm1.btSearchPortsClick(Sender: TObject);
begin
  cmbPortaSerial.Items.Clear;
  ACBrBAL1.Device.AcharPortasSeriais( cmbPortaSerial.Items );
  {$IfDef MSWINDOWS}
   ACBrBAL1.Device.AcharPortasUSB( cmbPortaSerial.Items );
  {$EndIf}
  {$IfDef HAS_BLUETOOTH}
   ACBrBAL1.Device.AcharPortasBlueTooth( cmbPortaSerial.Items, True );
  {$EndIf}

  cmbPortaSerial.Items.Add('LPT1') ;
  cmbPortaSerial.Items.Add('TCP:192.168.0.31:9100') ;

  {$IfNDef MSWINDOWS}
   cmbPortaSerial.Items.Add('/dev/ttyS0') ;
   cmbPortaSerial.Items.Add('/dev/ttyUSB0') ;
  {$EndIf}
end;

procedure TForm1.btZerarDispositivoClick(Sender: TObject);
begin
  if (ACBrBAL1.BAL is TACBrBALSelfCheckout) then
    TACBrBALSelfCheckout(ACBrBAL1.BAL).ZerarDispositivo;
end;

procedure TForm1.edtTimeOutKeyPress(Sender: TObject; var Key: Char);
begin
  if not (Key in ['0'..'9',#13,#8]) then
     Key := #0 ;
end;

procedure TForm1.chbMonitorarClick(Sender: TObject);
begin
   ACBrBAL1.MonitorarBalanca := chbMonitorar.Checked ;
end;

procedure TForm1.ACBrBAL1LePeso(Peso: Double; Resposta: AnsiString);
var
  valid: Integer;
begin
   sttPeso.Caption     := formatFloat('##0.000', Peso );
   sttResposta.Caption := Converte( Resposta ) ;

   if Peso > 0 then
      Memo1.Lines.Text := 'Leitura OK !'
   else
    begin
      valid := Trunc(ACBrBAL1.UltimoPesoLido);
      case valid of
         0 : Memo1.Lines.Text := 'TimeOut !'+sLineBreak+
                                 'Coloque o produto sobre a Balana!' ;
        -1 : Memo1.Lines.Text := 'Peso Instavel ! ' +sLineBreak+
                                 'Tente Nova Leitura' ;
        -2 : Memo1.Lines.Text := 'Peso Negativo !' ;
       -10 : Memo1.Lines.Text := 'Sobrepeso !' ;
      end;
    end ;
end;

procedure TForm1.FormCreate(Sender : TObject) ;
var
  I : TACBrBALModelo ;
begin
  cmbBalanca.Items.Clear ;
  For I := Low(TACBrBALModelo) to High(TACBrBALModelo) do
     cmbBalanca.Items.Add( GetEnumName(TypeInfo(TACBrBALModelo), integer(I) ) ) ;
  cmbBalanca.ItemIndex := 0;
end;

procedure TForm1.SbArqLogClick(Sender: TObject);
begin
  OpenURL( ExtractFilePath( Application.ExeName ) + edLog.Text);
end;

procedure TForm1.FormClose(Sender: TObject; var CloseAction: TCloseAction);
begin
  ACBrBAL1.Desativar ;
end;

end.

